#!/usr/bin/env node
'use strict';

require('dotenv').config()

const FORMAT_JSON = "json";
const FORMAT_QIF = "qif";

const KontistClient = require("../kontist-client");
const kontist = new KontistClient({ user: process.env.KONTIST_USER, password: process.env.KONTIST_PASSWORD });
const format = process.argv[2] || FORMAT_JSON;

kontist.getAccounts()
    .then((account) => {
        return kontist.getTransactions(account[0].id);
    }, (error) => { throw error })
    .then((transactions) => {
        switch (format) {
            case FORMAT_JSON: {
                process.stdout.write(JSON.stringify(transactions, null, 4));
                break;
            }
            case FORMAT_QIF: {
                const qif = require('qif-writer');
                const data = transactions.map((row) => ({
                    date: new Date(row.date).toLocaleDateString("en-US"),
                    amount: row.amount / 100,
                    payee: row.name,
                    memo: row.purpose
                }));
                qif.write(data, { type: 'Bank' });
                break;
            }
            default:
                throw new Error("Unknown format " + format);
        }
    }, (error) => { throw error })
    .catch((error) => {
        console.error(error);
    });
