#!/usr/bin/env node
'use strict';

require('dotenv').config()
const KontistClient = require("../kontist-client");
const kontist = new KontistClient({ user: process.env.KONTIST_USER, password: process.env.KONTIST_PASSWORD });
const program = require('commander');

program
    .command('list', 'list all transfers')
    .action(() => {
        kontist.getAccounts()
            .then((account) => {
                return kontist.getTransfers(account[0].id);
            }, (error) => { throw error })
            .then((transactions) => {
                process.stdout.write(JSON.stringify(transactions, null, 4));
            }, (error) => { throw error })
            .catch((error) => {
                console.error(error);
            });
    });


program
    .command('init <recipient> <iban> <amount> <note>', 'initiate a transfer, amount is EUR in cents')
    .action((recipient, iban, amount, note) => {
        kontist.getAccounts()
            .then((account) => {
                return kontist.initiateTransfer(account[0].id, recipient, iban, +amount, note);
            }, (error) => { throw error })
            .then((result) => {
                process.stdout.write(JSON.stringify(result, null, 4));
            }, (error) => { throw error })
            .catch((error) => {
                console.error(error);
            });
    });


program
    .command('confirm <transferId> <token> <recipient> <iban> <amount> <note>', 'confirm a transfer, use transferId from init call and token from sms')
    .action((transferId, token, recipient, iban, amount, note) => {
        kontist.getAccounts()
            .then((account) => {
                return kontist.confirmTransfer(account[0].id, transferId, token, recipient, iban, +amount, note);
            }, (error) => { throw error })
            .then((result) => {
                process.stdout.write(JSON.stringify(result, null, 4));
            }, (error) => { throw error })
            .catch((error) => {
                console.error(error);
            });
    });

program.parse(process.argv);
if (!process.argv.slice(2).length) {
    program.outputHelp();
}
